@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef CALENDARTESTUTILS_H_
-#define CALENDARTESTUTILS_H_
+#pragma once
 
 #include "types.h"
 #include "calendar.h"
@@ -14,5 +13,4 @@
 KGAPI2::CalendarPtr calendarFromFile(const QString &path);
 KGAPI2::EventPtr eventFromFile(const QString &path);
 
-#endif
 
