@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI_FAKENETWORKACCESSMANAGER_H_
-#define KGAPI_FAKENETWORKACCESSMANAGER_H_
+#pragma once
 
 #include <QNetworkAccessManager>
 #include <QList>
@@ -53,4 +52,3 @@ private:
 };
 
 
-#endif
