@@ -9,48 +9,28 @@
 #pragma once
 
 #include <QMainWindow>
+#include "ui_mainwindow.h"
 
-#include <types.h>
-
-namespace Ui {
-    class MainWindow;
-}
+#include "core/types.h"
 
 namespace KGAPI2 {
   class Job;
 }
 
-
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
 
   public:
     explicit MainWindow(QWidget *parent = nullptr);
-    ~MainWindow() override;
 
   private Q_SLOTS:
     /**
      * Retrieves tokens from Google that we will use to authenticate
-     * fursther requests
+     * further requests
      */
     void authenticate();
 
-    /**
-     * Authentication has finished
-     */
-    void slotAuthJobFinished(KGAPI2::Job *job);
-
-    /**
-     * All contacts were fetched.
-     */
-    void slotFetchJobFinished(KGAPI2::Job *job);
-
-    /**
-     * Contact details were fetched.
-     */
-    void slotContactFetchJobFinished(KGAPI2::Job *job);
-
     /**
      * Retrieves list of all contacts from user's Google Contacts
      * addressbook
@@ -64,7 +44,7 @@ class MainWindow : public QMainWindow
     void contactSelected();
 
   private:
-    Ui::MainWindow *m_ui;
+    Ui::MainWindow ui;
 
     KGAPI2::AccountPtr m_account;
 
