@@ -5,62 +5,41 @@
 */
 
 
-#ifndef MAINWINDOW_H
-#define MAINWINDOW_H
+#pragma once
 
 #include <QMainWindow>
+#include "ui_mainwindow.h"
 
-#include <types.h>
-
-namespace Ui {
-    class MainWindow;
-}
+#include "core/types.h"
 
 namespace KGAPI2 {
   class Job;
 }
 
-
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
 
-  public:
+public:
     explicit MainWindow(QWidget *parent = nullptr);
-    ~MainWindow() override;
 
-  private Q_SLOTS:
+private Q_SLOTS:
     /**
      * Retrieves tokens from Google that we will use to authenticate
-     * fursther requests
+     * further requests
      */
     void authenticate();
 
-    /**
-     * Authentication has finished
-     */
-    void slotAuthJobFinished(KGAPI2::Job *job);
-
     /**
      * Creates the Drive with name in newDrivesEdit
      */
     void createDrives();
 
-    /**
-     * Drive was created.
-     */
-    void slotDrivesCreateJobFinished(KGAPI2::Job *job);
-
     /**
      * Rename the selected Drive with name in renameDrivesEdit
      */
     void renameSelectedDrives();
 
-    /**
-     * Drive was modified.
-     */
-    void slotDrivesModifyJobFinished(KGAPI2::Job *job);
-
     /**
      * Hide the selected Drive
      */
@@ -76,16 +55,6 @@ class MainWindow : public QMainWindow
      */
     void slotDrivesHideJobFinished(KGAPI2::Job *job);
 
-    /**
-     * All Drives were fetched.
-     */
-    void slotFetchJobFinished(KGAPI2::Job *job);
-
-    /**
-     * Drive listing was fetched.
-     */
-    void slotDrivesFetchJobFinished(KGAPI2::Job *job);
-
     /**
      * Retrieves list of all drives from user's Google drives
      */
@@ -96,14 +65,9 @@ class MainWindow : public QMainWindow
      */
     void deleteSelectedDrives();
 
-    /**
-     * Drive was deleted.
-     */
-    void slotDrivesDeleteJobFinished(KGAPI2::Job *job);
-
     /**
      * A specific team drive in drives list has been selected. Sends a request
-     * to Google to retrieve teh team drive file list.
+     * to Google to retrieve the team drive file list.
      */
     void drivesSelected();
 
@@ -113,16 +77,10 @@ class MainWindow : public QMainWindow
      */
     void drivesItemSelected();
 
-    /**
-     * Drive item detail was fetched.
-     */
-    void slotDrivesItemFetchJobFinished(KGAPI2::Job *job);
-
-  private:
-    Ui::MainWindow *m_ui;
+private:
+    Ui::MainWindow ui;
 
     KGAPI2::AccountPtr m_account;
 
 };
 
-#endif // MAINWINDOW_H
