@@ -1,25 +1,10 @@
 /*
- * Copyright (C) 2014  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2014 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_BLOGGER_COMMENTFETCHJOB_H
-#define KGAPI2_BLOGGER_COMMENTFETCHJOB_H
+#pragma once
 
 #include "fetchjob.h"
 #include "kgapiblogger_export.h"
@@ -89,4 +74,3 @@ class KGAPIBLOGGER_EXPORT CommentFetchJob : public KGAPI2::FetchJob
 } // namespace Blogger
 } // namespace KGAPI2
 
-#endif // KGAPI2_BLOGGER_COMMENTFETCHJOB_H
