@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_BLOGGER_POSTCREATEJOB_H
-#define KGAPI2_BLOGGER_POSTCREATEJOB_H
+#pragma once
 
 #include "createjob.h"
 #include "kgapiblogger_export.h"
@@ -38,4 +37,3 @@ class KGAPIBLOGGER_EXPORT PostCreateJob : public KGAPI2::CreateJob
 }
 }
 
-#endif // KGAPI2_BLOGGER_POSTCREATEJOB_H
