@@ -154,8 +154,9 @@ void PostFetchJob::start()
         if (d->maxResults > 0) {
             query.addQueryItem(QStringLiteral("maxResults"), QString::number(d->maxResults));
         }
-        if (!d->filterLabels.isEmpty())
+        if (!d->filterLabels.isEmpty()) {
             query.addQueryItem(QStringLiteral("labels"), d->filterLabels.join(QLatin1Char(',')));
+        }
         query.addQueryItem(QStringLiteral("fetchBodies"), Utils::bool2Str(d->fetchBodies));
         query.addQueryItem(QStringLiteral("fetchImages"), Utils::bool2Str(d->fetchImages));
     }
