@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_EVENTFETCHJOB_H
-#define LIBKGAPI2_EVENTFETCHJOB_H
+#pragma once
 
 #include "fetchjob.h"
 #include "kgapicalendar_export.h"
@@ -247,4 +246,3 @@ class KGAPICALENDAR_EXPORT EventFetchJob : public KGAPI2::FetchJob
 
 } // namespace KGAPI2
 
-#endif // LIBKGAPI2_EVENTFETCHJOB_H
