@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_CONTACTSGROUPFETCHJOB_H
-#define LIBKGAPI2_CONTACTSGROUPFETCHJOB_H
+#pragma once
 
 #include "fetchjob.h"
 #include "kgapicontacts_export.h"
@@ -78,4 +77,3 @@ class KGAPICONTACTS_EXPORT ContactsGroupFetchJob : public KGAPI2::FetchJob
 
 } // namespace KGAPI2
 
-#endif // LIBKGAPI2_CONTACTSGROUPFETCHJOB_H
