@@ -9,6 +9,7 @@
 #include "contactsgroup.h"
 #include "utils.h"
 #include "../debug.h"
+#include <kcontacts_version.h>
 
 #include <QDomDocument>
 #include <QDomElement>
@@ -27,7 +28,7 @@ namespace ContactsService
 
 namespace Private
 {
-    QString stringFromXMLMap(const QVariantMap &map, const QString &key) {
+    static QString stringFromXMLMap(const QVariantMap &map, const QString &key) {
         const QVariantMap t = map.value(key).toMap();
         return t.value(QStringLiteral("$t")).toString();
     }
@@ -40,7 +41,7 @@ namespace Private
     static const QString ContactsGroupBasePath(QStringLiteral("/m8/feeds/groups"));
     static const QString PhotoBasePath(QStringLiteral("/m8/feeds/photos/media"));
 
-    QByteArray addRelSchema(const QByteArray &rel)
+    static QByteArray addRelSchema(const QByteArray &rel)
     {
         if (!rel.startsWith("http://schemas.google.com/g/2005#")) {
             return "http://schemas.google.com/g/2005#" + rel;
@@ -422,24 +423,24 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
             if (rel == QLatin1String("home-page")) {
                 KContacts::ResourceLocatorUrl locator;
                 locator.setUrl(url);
-                locator.setParameters({ { QStringLiteral("TYPE"), { QStringLiteral("HOME") } } });
+                locator.setType(KContacts::ResourceLocatorUrl::Home);
                 contact->insertExtraUrl(locator);
             } else if (rel == QLatin1String("work")) {
                 KContacts::ResourceLocatorUrl locator;
                 locator.setUrl(url);
-                locator.setParameters({ { QStringLiteral("TYPE"), { QStringLiteral("WORK") } } });
+                locator.setType(KContacts::ResourceLocatorUrl::Work);
                 contact->insertExtraUrl(locator);
             } else if (rel == QLatin1String("profile")) {
                 KContacts::ResourceLocatorUrl locator;
                 locator.setUrl(url);
-                locator.setParameters({ { QStringLiteral("TYPE"), { QStringLiteral("PROFILE") } } });
+                locator.setType(KContacts::ResourceLocatorUrl::Profile);
                 contact->insertExtraUrl(locator);
             } else if (rel == QLatin1String("blog")) {
                 contact->setBlogFeed(url);
             } else {
                 KContacts::ResourceLocatorUrl locator;
                 locator.setUrl(url);
-                locator.setParameters({ { QStringLiteral("TYPE"), { rel } } });
+                locator.setType(KContacts::ResourceLocatorUrl::Other);
                 contact->insertExtraUrl(locator);
             }
         }
@@ -450,9 +451,16 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
     for (const QVariant & em : emails) {
         const QVariantMap email = em.toMap();
         const auto emailType = Contact::emailSchemeToProtocolName(email.value(QStringLiteral("rel")).toString());
-        const QMap<QString, QStringList> params({ { QStringLiteral("TYPE"), { emailType } } });
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
+        const QMap<QString, QStringList> params({ { QStringLiteral("type"), { emailType } } });
         contact->insertEmail(email.value(QStringLiteral("address")).toString(),
                              email.value(QStringLiteral("primary")).toBool(), params);
+#else
+        KContacts::Email emailAddress(email.value(QStringLiteral("address")).toString());
+        emailAddress.setType(Contact::emailSchemeToProtocolType(emailType));
+        emailAddress.setPreferred(email.value(QStringLiteral("primary")).toBool());
+        contact->addEmail(emailAddress);
+#endif
     }
 
     /* IMs */
@@ -677,11 +685,18 @@ QByteArray contactToXML(const ContactPtr& contact)
     /* URLs */
     const auto extraUrls = contact->extraUrlList();
     for (const auto &extraUrl : extraUrls) {
-        const auto rels = extraUrl.parameters().value(QStringLiteral("TYPE"));
-        auto rel = rels.isEmpty() ? "other" : rels.at(0).toLower().toUtf8();
-        if (rel == "home") {
+        const auto type = extraUrl.type();
+        QByteArray rel;
+        if (type & KContacts::ResourceLocatorUrl::Other || type & KContacts::ResourceLocatorUrl::Unknown) {
+            rel = "other";
+        } else if (type & KContacts::ResourceLocatorUrl::Home) {
             rel = "home-page";
+        } else if (type & KContacts::ResourceLocatorUrl::Work) {
+            rel = "work";
+        } else if (type & KContacts::ResourceLocatorUrl::Profile) {
+            rel = "profile";
         }
+
         output.append("<gContact:website rel=\"" + rel + "\" href=\"" + extraUrl.url().toString().toHtmlEscaped().toUtf8() + "\" />");
     }
 
@@ -689,9 +704,17 @@ QByteArray contactToXML(const ContactPtr& contact)
     const auto preferredEmail = contact->preferredEmail();
     const auto emailList = contact->emailList();
     for(const auto &email : emailList) {
-        const auto rels = email.parameters().value(QStringLiteral("TYPE"), { QStringLiteral("home") });
-        const auto rel = Private::addRelSchema(rels.isEmpty() ? "home" : rels.at(0).toLower().toUtf8());
-        output.append("<gd:email rel='" + rel + "' address='").append(email.mail().toHtmlEscaped().toUtf8()).append("'");
+        const auto type = email.type();
+        QByteArray rel;
+        if (type & KContacts::Email::Home || type & KContacts::Email::Unknown) {
+            rel = Private::addRelSchema("home");
+        } else if (type & KContacts::Email::Work) {
+            rel = Private::addRelSchema("work");
+        } else if (type & KContacts::Email::Other) {
+            rel = Private::addRelSchema("other");
+        }
+
+        output.append("<gd:email rel='" + rel + "' address='" + email.mail().toHtmlEscaped().toUtf8() + "'");
         if (email.mail() == preferredEmail) {
             output.append(" primary=\"true\"");
         }
@@ -743,18 +766,24 @@ QByteArray contactToXML(const ContactPtr& contact)
         .append(Contact::addressTypeToScheme(address.type()).toUtf8())
         .append("'>");
 
-        if (!address.locality().isEmpty())
+        if (!address.locality().isEmpty()) {
             output.append("<gd:city>").append(address.locality().toHtmlEscaped().toUtf8()).append("</gd:city>");
-        if (!address.street().isEmpty())
+        }
+        if (!address.street().isEmpty()) {
             output.append("<gd:street>").append(address.street().toHtmlEscaped().toUtf8()).append("</gd:street>");
-        if (!address.region().isEmpty())
+        }
+        if (!address.region().isEmpty()) {
             output.append("<gd:region>").append(address.region().toHtmlEscaped().toUtf8()).append("</gd:region>");
-        if (!address.postalCode().isEmpty())
+        }
+        if (!address.postalCode().isEmpty()) {
             output.append("<gd:postcode>").append(address.postalCode().toHtmlEscaped().toUtf8()).append("</gd:postcode>");
-        if (!address.country().isEmpty())
+        }
+        if (!address.country().isEmpty()) {
             output.append("<gd:country>").append(address.country().toHtmlEscaped().toUtf8()).append("</gd:country>");
-        if (!address.formattedAddress().isEmpty())
+        }
+        if (!address.formattedAddress().isEmpty()) {
             output.append("<gd:formattedAddress>").append(address.formattedAddress().toHtmlEscaped().toUtf8()).append("</gd:formattedAddress>");
+        }
         output.append("</gd:structuredPostalAddress>");
     }
 
@@ -779,8 +808,9 @@ QByteArray contactToXML(const ContactPtr& contact)
     if ((!groups.isEmpty()) && !groups.at(0).isEmpty()) {
         for (const QString & group :groups) {
             bool removed = contact->groupIsDeleted(group);
-            if (!removed)
+            if (!removed) {
                 output.append(QStringLiteral("<gContact:groupMembershipInfo deleted=\"false\" href=\"%2\" />").arg(group).toUtf8());
+            }
         }
     }
     parsedCustoms << QStringLiteral("GCALENDAR-groupMembershipInfo");
@@ -871,9 +901,9 @@ ContactPtr XMLToContact(const QByteArray& xmlData)
         }
 
         if (e.tagName() == QLatin1String("gd:name")) {
-            QDomNodeList l = e.childNodes();
-            for (int i = 0; i < l.length(); ++i) {
-                const QDomElement el = l.at(i).toElement();
+            const QDomNodeList l = e.childNodes();
+            for (int j = 0; j < l.length(); ++j) {
+                const QDomElement el = l.at(j).toElement();
 
                 if (el.tagName() == QLatin1String("gd:fullName")) {
                     contact->setFormattedName(el.text());
@@ -1017,11 +1047,17 @@ ContactPtr XMLToContact(const QByteArray& xmlData)
             }
 
             KContacts::ResourceLocatorUrl url;
-            QString rel = e.attribute(QStringLiteral("rel")).toUpper();
+            QString rel = e.attribute(QStringLiteral("rel")).toLower();
             if (rel == QLatin1String("home-page")) {
-                rel = QStringLiteral("HOME");
+                url.setType(KContacts::ResourceLocatorUrl::Home);
+            } else if (rel == QLatin1String("work")) {
+                url.setType(KContacts::ResourceLocatorUrl::Work);
+            } else if (rel == QLatin1String("profile")) {
+                url.setType(KContacts::ResourceLocatorUrl::Profile);
+            } else {
+                url.setType(KContacts::ResourceLocatorUrl::Other);
             }
-            url.setParameters({ { QStringLiteral("TYPE"), { rel } } });
+
             url.setUrl(QUrl(e.attribute(QStringLiteral("href"), {})));
             contact->insertExtraUrl(url);
 
@@ -1031,9 +1067,20 @@ ContactPtr XMLToContact(const QByteArray& xmlData)
         /* Emails */
         if (e.tagName() == QLatin1String("gd:email")) {
             const auto emailType = Contact::emailSchemeToProtocolName(e.attribute(QStringLiteral("rel"), {}));
-            const QMap<QString, QStringList> params({ { QStringLiteral("TYPE"), { emailType } } });
+
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
+            const QMap<QString, QStringList> params({ { QStringLiteral("type"), { emailType } } });
             contact->insertEmail(e.attribute(QStringLiteral("address")),
                                  (e.attribute(QStringLiteral("primary")).toLower() == QLatin1String("true")), params);
+#else
+            KContacts::Email emailAddress(e.attribute(QStringLiteral("address")));
+            emailAddress.setType(Contact::emailSchemeToProtocolType(emailType));
+            emailAddress.setPreferred(e.attribute(QStringLiteral("primary")).toLower() == QLatin1String("true"));
+            contact->addEmail(emailAddress);
+#endif
+
+
+
             continue;
         }
 
