@@ -1,25 +1,10 @@
 /*
-    Copyright 2012  Dan Vratil <dan@progdan.cz>
+    SPDX-FileCopyrightText: 2012-2018 Daniel Vrátil <dvratil@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_ACCOUNT_H
-#define LIBKGAPI2_ACCOUNT_H
+#pragma once
 
 #include <QString>
 #include <QUrl>
@@ -33,11 +18,11 @@ namespace KGAPI2
 {
 
 /**
- * @headerfile Account
+ * @headerfile account.h
  * @brief A Google account
  *
  * This class represents a single Google account. The account is uniquely
- * identified by Account::accountName (which is actually user's GMail address).
+ * identified by Account::accountName (which is actually the user's GMail address).
  *
  * The class stores an access token, refresh token (to retrieve a new access token
  * when the old one expires) and list of scopes (APIs that current access token
@@ -82,6 +67,9 @@ class KGAPICORE_EXPORT Account
      */
     virtual ~Account();
 
+
+    bool operator==(const Account &other) const;
+
     /**
      * @returns Returns unique account identifier
      */
@@ -198,6 +186,15 @@ class KGAPICORE_EXPORT Account
      */
     static QUrl bloggerScopeUrl();
 
+    /**
+     * Returns scope URL for Gmail service.
+     */
+    static QUrl mailScopeUrl();
+
+    /**
+     * Returns scope URL for Drive service.
+     */
+    static QUrl driveScopeUrl();
 private:
     class Private;
     Private * const d;
@@ -224,4 +221,3 @@ private:
 
 Q_DECLARE_METATYPE(KGAPI2::AccountPtr)
 
-#endif // LIBKGAPI2_ACCOUNT_H
