@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_FULLAUTHENTICATIONJOB_P_H_
-#define LIBKGAPI2_FULLAUTHENTICATIONJOB_P_H_
+#pragma once
 
 #include "job.h"
 #include "kgapicore_export.h"
@@ -45,6 +44,5 @@ private:
 
 } // namespace KGAPI2
 
-#endif
 
 
