@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_PRIVATE_NEWTOKENSFETCHJOB_P_H
-#define LIBKGAPI2_PRIVATE_NEWTOKENSFETCHJOB_P_H
+#pragma once
 
 #include "job.h"
 #include "kgapicore_export.h"
@@ -44,4 +43,3 @@ class KGAPICORE_EXPORT NewTokensFetchJob : public KGAPI2::Job
 
 } // namespace KGAPI2
 
-#endif // LIBKGAPI2_PRIVATE_NEWTOKENSFETCHJOB_P_H
