@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_UTILS_P_H
-#define LIBKGAPI2_UTILS_P_H
+#pragma once
 
 #include "utils.h"
 #include "../debug.h"
@@ -32,5 +31,4 @@
         } \
     }
 
-#endif // LIBKGAPI2_UTILS_P_H
 
