@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_DRIVE_CHANGE_H
-#define LIBKGAPI2_DRIVE_CHANGE_H
+#pragma once
 
 #include "types.h"
 #include "object.h"
@@ -80,4 +79,3 @@ class KGAPIDRIVE_EXPORT Change: public KGAPI2::Object
 
 } /* namespace KGAPI2 */
 
-#endif // LIBKGAPI2_DRIVE_CHANGE_H
