@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_DRIVEFILE_P_H
-#define LIBKGAPI2_DRIVEFILE_P_H
+#pragma once
 
 #include "file.h"
 
@@ -70,4 +69,3 @@ class Q_DECL_HIDDEN File::Private
 
 } // namespace KGAPI2
 
-#endif // LIBKGAPI2_DRIVEFILE_P_H
