@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_DRIVEFILEABSTRACTUPLOADJOB_H
-#define KGAPI2_DRIVEFILEABSTRACTUPLOADJOB_H
+#pragma once
 
 #include "file.h"
 #include "fileabstractdatajob.h"
@@ -79,4 +78,3 @@ class KGAPIDRIVE_EXPORT FileAbstractUploadJob : public KGAPI2::Drive::FileAbstra
 
 } // namespace KGAPI2
 
-#endif // KGAPI2_DRIVEFILEABSTRACTUPLOADJOB_H
