@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_DRIVEFILECOPYJOB_H
-#define KGAPI2_DRIVEFILECOPYJOB_H
+#pragma once
 
 #include "fileabstractdatajob.h"
 #include "kgapidrive_export.h"
@@ -62,4 +61,3 @@ class KGAPIDRIVE_EXPORT FileCopyJob : public KGAPI2::Drive::FileAbstractDataJob
 
 } // namespace KGAPI2
 
-#endif // KGAPI2_DRIVEFILECOPYJOB_H
