@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_DRIVEFILEFETCHJOB_H
-#define KGAPI2_DRIVEFILEFETCHJOB_H
+#pragma once
 
 #include "fetchjob.h"
 #include "kgapidrive_export.h"
@@ -110,4 +109,3 @@ class KGAPIDRIVE_EXPORT FileFetchJob : public KGAPI2::FetchJob
 
 } // namespace KGAPI2
 
-#endif // KGAPI2_DRIVEFILEFETCHJOB_H
