@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_DRIVEFILERESUMABLEMODIFYJOB_H
-#define KGAPI2_DRIVEFILERESUMABLEMODIFYJOB_H
+#pragma once
 
 #include "fileabstractresumablejob.h"
 #include "kgapidrive_export.h"
@@ -93,4 +92,3 @@ class KGAPIDRIVE_EXPORT FileResumableModifyJob : public KGAPI2::Drive::FileAbstr
 
 } // namespace KGAPI2
 
-#endif // KGAPI2_DRIVEFILERESUMABLEMODIFYJOB_H
