@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_DRIVEPARENTREFERENCE_P_H
-#define LIBKGAPI2_DRIVEPARENTREFERENCE_P_H
+#pragma once
 
 #include "parentreference.h"
 
@@ -38,4 +37,3 @@ class Q_DECL_HIDDEN ParentReference::Private
 
 } // namespace KGAPI2
 
-#endif // LIBKGAPI2_DRIVEPARENTREFERENCE_P_H
