@@ -1,27 +1,12 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_DRIVEPERMISSIONCREATEJOB_H
-#define KGAPI2_DRIVEPERMISSIONCREATEJOB_H
+#pragma once
 
 #include "createjob.h"
 #include "kgapidrive_export.h"
@@ -45,6 +30,30 @@ class KGAPIDRIVE_EXPORT PermissionCreateJob : public KGAPI2::CreateJob
                                  const AccountPtr &account, QObject *parent = nullptr);
     ~PermissionCreateJob() override;
 
+    /**
+     * @brief The plain text custom message to include in notification emails.
+     */
+    QString emailMessage() const;
+
+    /**
+     * @brief Sets the plain text custom message to include in notification emails.
+     */
+    void setEmailMessage(const QString &emailMessage);
+
+    /**
+     * @brief Sets whether to send notification emails when sharing to users
+     * or groups. This parameter is ignored and an email is sent if the role
+     * is owner. (Default: true)
+     */
+    bool sendNotificationEmails() const;
+
+    /**
+     * @brief Whether to send notification emails when sharing to users or
+     * groups. This parameter is ignored and an email is sent if the role
+     * is owner. (Default: true)
+     */
+    void setSendNotificationEmails(bool sendNotificationEmails);
+
     /**
      * @brief Whether the request supports both My Drives and shared drives.
      *
@@ -65,6 +74,22 @@ class KGAPIDRIVE_EXPORT PermissionCreateJob : public KGAPI2::CreateJob
      */
     KGAPIDRIVE_DEPRECATED void setSupportsAllDrives(bool supportsAllDrives);
 
+    /**
+     * @brief Issue the request as a domain administrator; if set to true,
+     * then the requester will be granted access if the file ID parameter refers
+     * to a shared drive and the requester is an administrator of the domain to
+     * which the shared drive belongs. (Default: false)
+     */
+    bool useDomainAdminAccess() const;
+
+    /**
+     * @brief Sets to issue the request as a domain administrator; if set to true,
+     * then the requester will be granted access if the file ID parameter refers
+     * to a shared drive and the requester is an administrator of the domain to
+     * which the shared drive belongs. (Default: false)
+     */
+    void setUseDomainAdminAccess(bool useDomainAdminAccess);
+
   protected:
     void start() override;
     KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
@@ -72,7 +97,7 @@ class KGAPIDRIVE_EXPORT PermissionCreateJob : public KGAPI2::CreateJob
 
   private:
     class Private;
-    Private *const d;
+    QScopedPointer<Private> d;
     friend class Private;
 };
 
@@ -80,4 +105,3 @@ class KGAPIDRIVE_EXPORT PermissionCreateJob : public KGAPI2::CreateJob
 
 } // namespace KGAPI2
 
-#endif // KGAPI2_DRIVEPERMISSIONCREATEJOB_H
