@@ -5,8 +5,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef KGAPI2_DRIVEUSER_H
-#define KGAPI2_DRIVEUSER_H
+#pragma once
 
 #include "types.h"
 #include "kgapidrive_export.h"
@@ -67,4 +66,3 @@ class KGAPIDRIVE_EXPORT User
 
 } // namespace KGAPI2
 
-#endif // KGAPI2_DRIVEUSER_H
