@@ -40,7 +40,8 @@ LocationPtr JSONToLocation(const QByteArray & jsonData)
 
 QByteArray locationToJSON(const LocationPtr &location)
 {
-    QVariantMap map, output;
+    QVariantMap map;
+    QVariantMap output;
 
     map.insert(QStringLiteral("kind"), QStringLiteral("latitude#location"));
     map.insert(QStringLiteral("latitude"), QString::number(location->latitude()));
@@ -73,7 +74,7 @@ QByteArray locationToJSON(const LocationPtr &location)
 
 ObjectsList parseLocationJSONFeed(const QByteArray & jsonFeed, FeedData & feedData)
 {
-    Q_UNUSED(feedData);
+    Q_UNUSED(feedData)
 
     ObjectsList output;
 
@@ -209,7 +210,7 @@ QUrl insertLocationUrl()
 
 QUrl deleteLocationUrl(const qlonglong id)
 {
-    Q_UNUSED(id);
+    Q_UNUSED(id)
     QUrl url(Private::GoogleApisUrl);
     url.setPath(Private::LocationBasePath);
     return url;
