@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_LOCATIONFETCHJOB_H
-#define LIBKGAPI2_LOCATIONFETCHJOB_H
+#pragma once
 
 #include "fetchjob.h"
 #include "latitude.h"
@@ -101,4 +100,3 @@ class KGAPILATITUDE_DEPRECATED_EXPORT LocationFetchJob : public KGAPI2::FetchJob
 
 } // namespace KGAPI2
 
-#endif // LIBKGAPI2_LOCATIONFETCHJOB_H
