@@ -1,23 +1,9 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "taskcreatejob.h"
@@ -34,12 +20,18 @@
 
 using namespace KGAPI2;
 
+namespace {
+    static const auto ParentParam = QStringLiteral("parent");
+    static const auto PreviousParam = QStringLiteral("previous");
+}
+
 class Q_DECL_HIDDEN TaskCreateJob::Private
 {
   public:
     QueueHelper<TaskPtr> tasks;
     QString taskListId;
     QString parentId;
+    QString previousId;
 };
 
 TaskCreateJob::TaskCreateJob(const TaskPtr& task, const QString& taskListId,
@@ -60,10 +52,7 @@ TaskCreateJob::TaskCreateJob(const TasksList& tasks, const QString& taskListId,
     d->taskListId = taskListId;
 }
 
-TaskCreateJob::~TaskCreateJob()
-{
-    delete d;
-}
+TaskCreateJob::~TaskCreateJob() = default;
 
 QString TaskCreateJob::parentItem() const
 {
@@ -80,6 +69,21 @@ void TaskCreateJob::setParentItem(const QString &parentId)
     d->parentId = parentId;
 }
 
+QString TaskCreateJob::previous() const
+{
+    return d->previousId;
+}
+
+void TaskCreateJob::setPrevious(const QString &previousId)
+{
+    if (isRunning()) {
+        qCWarning(KGAPIDebug) << "Can't modify previous property when job is running!";
+        return;
+    }
+
+    d->previousId = previousId;
+}
+
 void TaskCreateJob::start()
 {
    if (d->tasks.atEnd()) {
@@ -92,20 +96,16 @@ void TaskCreateJob::start()
     QUrl url = TasksService::createTaskUrl(d->taskListId);
     QUrlQuery query(url);
     if (!d->parentId.isEmpty()) {
-        query.addQueryItem(QStringLiteral("parent"), d->parentId);
+        query.addQueryItem(ParentParam, d->parentId);
+    }
+    if (!d->previousId.isEmpty()) {
+        query.addQueryItem(PreviousParam, d->previousId);
     }
     url.setQuery(query);
     QNetworkRequest request(url);
 
     const QByteArray rawData = TasksService::taskToJSON(task);
 
-    QStringList headers;
-    const auto rawHeaderList = request.rawHeaderList();
-    headers.reserve(rawHeaderList.size());
-    for (const QByteArray &str : qAsConst(rawHeaderList)) {
-        headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
-    }
-
     enqueueRequest(request, rawData, QStringLiteral("application/json"));
 }
 
