@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_TASKLISTDELETEJOB_H
-#define LIBKGAPI2_TASKLISTDELETEJOB_H
+#pragma once
 
 #include "deletejob.h"
 #include "kgapitasks_export.h"
@@ -106,4 +105,3 @@ class KGAPITASKS_EXPORT TaskListDeleteJob : public KGAPI2::DeleteJob
 
 } // namespace KGAPI2
 
-#endif // LIBKGAPI2_TASKLISTDELETEJOB_H
