@@ -63,7 +63,7 @@ void TaskModifyJob::start()
     QStringList headers;
     const auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
-    for (const QByteArray &str : qAsConst(rawHeaderList)) {
+    for (const QByteArray &str : std::as_const(rawHeaderList)) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
 
