@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_TASKSSERVICE_H
-#define LIBKGAPI2_TASKSSERVICE_H
+#pragma once
 
 #include "kgapitasks_export.h"
 #include "types.h"
@@ -133,4 +132,3 @@ namespace TasksService
 
 } /* namespace KGAPI2 */
 
-#endif // LIBKGAPI2_TASKSSERVICE_H
